package com.pwt.web.mapper;

import java.util.List;
import com.pwt.web.domain.PwtBattery;
import org.apache.ibatis.annotations.Param;

/**
 * 电池管理Mapper接口
 * 
 * @author linyun
 * @date 2022-11-17
 */
public interface PwtBatteryMapper 
{
    /**
     * 查询电池管理
     * 
     * @param batteryId 电池管理ID
     * @return 电池管理
     */
    public PwtBattery selectPwtBatteryById(Long batteryId);

    /**
     * 查询电池管理列表
     * 
     * @param pwtBattery 电池管理
     * @return 电池管理集合
     */
    public List<PwtBattery> selectPwtBatteryList(PwtBattery pwtBattery);

    /**
     * 新增电池管理
     * 
     * @param pwtBattery 电池管理
     * @return 结果
     */
    public int insertPwtBattery(PwtBattery pwtBattery);

    /**
     * 修改电池管理
     * 
     * @param pwtBattery 电池管理
     * @return 结果
     */
    public int updatePwtBattery(PwtBattery pwtBattery);

    /**
     * 删除电池管理
     * 
     * @param batteryId 电池管理ID
     * @return 结果
     */
    public int deletePwtBatteryById(Long batteryId);

    /**
     * 批量删除电池管理
     * 
     * @param batteryIds 需要删除的数据ID
     * @return 结果
     */
    public int deletePwtBatteryByIds(Long[] batteryIds);

    /**
     * @Description: 查询vin码是否唯一
     * @Author: linyun
     * @Date: 2022/11/19 14:23
     * @Param:[vin vin编码]
     * @Return:int
     **/
    public int checkVinUnique(@Param("vin") String vin);

    /**
     * @Description: 根据vin编码查询
     * @Author: linyun
     * @Date: 2022/11/19 14:33
     * @Param:[vin vin编码]
     * @Return:com.pwt.web.domain.PwtBattery
     **/
    public PwtBattery getByVinCode(@Param("vin") String vin);
}
